@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = "0.14";
+our $VERSION = "0.15";
 
 1;
 
@@ -24,7 +24,7 @@ App::Gre - A grep clone using Perl regexp's with better file filtering, defaults
 recursively starting with current directory.
 
 =item * Speed is accomplished by only searching files you want to
-search (see "gre -combos").
+search (see "gre -c").
 
 =item * Presentation is colorful and readable.
 
@@ -32,10 +32,10 @@ search (see "gre -combos").
 
 =head1 SYNOPSIS
 
-    gre [-help]
-        [-A[<n>]] [-B[<n>]] [-C[<n>]] [-combos] [-d=<depth>]
+    gre [-h] [-c]
+        [-A[<n>]] [-B[<n>]] [-C[<n>]] [-d<n>]
         [-f=<file>] [-i] [-k] [-l] [-L] [-m] [-o] [-p=<str>]
-        [-passthru] [-t] [-v] [-y<n>] [-X]
+        [-r=<regexp>] [-R=<regexp>] [-t] [-u] [-v] [-y<n>] [-x]
         [-[no]xbinary]
         [-[no][x][i][r][ext]=<str>]
         [-[no][x][i][name,path,line1][e]=<str>]
@@ -48,29 +48,31 @@ search (see "gre -combos").
     [<file>...]        list of files to include, if not provided will
                        be current directory.
 
-    -h, -?, -help      help text
     -A[<n>]            print n lines after the matching line, default 2
     -B[<n>]            print n lines before the matching line, default 2
     -C[<n>]            print n lines before and after the matching line, default 2
-    -combos            displays builtin filter combos (-perl, -html, -php, -js)
-    -d, -depth=<num>   max depth of file recursion (1 is no recursion)
-    -f, -file=<file>   provide a filename, as if it was an arg on the command line
-    -i, -ignorecase    case insensitive matches
+    -c                 displays builtin filter combos (-perl, -html, -php, -js)
+    -d<n>              max depth of file recursion (1 is no recursion)
+    -f=<file>          provide a filename, as if it was an arg on the command line
+    -h, -?, -help      help text
+    -i                 case insensitive matches
     -k                 disable color
     -l                 print files that match
     -L                 print files that don't match
-    -m, -multiline     multiline regexp matches
-    -o, -only          only output the matching part of the line
-    -p, -print=<str>   print customized parts of the match ($1, $&, etc. are available)
-    -passthru          pass all lines through, but highlight matches
+    -m                 multiline regexp matches
+    -o                 only output the matching part of the line
+    -p=<str>           print customized parts of the match ($1, $&, etc. are available)
+    -r=<regexp>        provide a regexp, as if it was an arg on the command line
+    -R=<regexp>        like -r but line must not match regexp
     -t                 print files that would be searched (ignore regexp)
-    -v, -invert        select non-matching lines
+    -u                 passthrough all lines, but highlight matches
+    -v                 select non-matching lines
+    -x                 disables builtin default excluding filters
     -y1                output style 1, grouped by file, and line number preceeding matches
     -y2                output style 2, classic grep style
     -y3                output style 3, no file/line info
-    -X                 disables builtin default excluding filters
     -[no]xbinary       filters out binary files
-    -[no][x][i][name][e]=<str>
+    -[no][x][i]name[e]=<str>
                        include files by name*
     -[no][x][i]path[e]=<str>
                        include files by full path name*
@@ -81,33 +83,26 @@ search (see "gre -combos").
     -[no]{perl,html,php,js,java,cc,...}
                        include files matching builtin filter combo*
 
-    * option names for file filters can include:
-      "no" filters files out,
-      "i" makes the regexp case insensitive,
-      "e" makes the match use string equality instead of regexp,
-      "r" makes the match use regexp instead of string equality,
-      "x" makes it an excluding filter
-
 =head1 DESCRIPTION
 
-The main point behind this grep clone is that it can do better file
-matching. For example if you want to search all files for the string
-foo, except dot files (names starting with a "."), you could write
+
+This grep clone is capable of filtering file names as well as file
+contents with regexps.  For example if you want to search all files
+whose name contains "bar" for the string "foo", you could write
 this:
 
-    $ gre -no='^\.' foo
+    $ gre -name=bar foo
 
 Only .c files:
 
-    $ gre -ext=c yup
+    $ gre -ext=c foo
 
 You can build up arbitrarily complex conditions to just search the
 files you want:
 
-    $ gre -X -ext=gz -noext=tar.gz
+    $ gre -ext=html -noext=min.html foo
 
-This would find all .gz files that aren't .tar.gz files. The -X is
-necessary to disable the binary file filter.
+This would find all .html files that aren't .min.html files.
 
 =head1 FILE FILTERING
 
@@ -124,8 +119,9 @@ will list all perl and php files. This:
     $ gre -perl -noname=foo -php
 
 will list all perl files, remove those whose name matches the regexp
-of foo, then add all php files. order counts. If you want all perl
-and php files whose name doesn't match foo, you need this:
+of foo, then add all php files. Order counts. Those php files might
+have "foo" in their name. If you want all perl and php files whose
+name doesn't match "foo", you need this:
 
     $ gre -perl -php -noname=foo
 
@@ -141,14 +137,17 @@ will only show perl files.
 will show all files except perl files.
 
 There are two levels of filtering that run independent of each
-other. The "includes" like -perl or -ext=c (.c extension) and the
-"excludes" like -x=foo or -xbinary. why independent?  consider the
-script added a default filter to remove all backup files (-x='~$')
-and which will have to mix with command line filters.  The following
-tries to search for bash files (files whose first line starts with
+other. One level is the "includes" filters like -perl, -nophp, or
+-ext=c.  The second level is the "excludes" filters like -xname=foo
+or -xbinary.
+
+Why are they independent?  Consider if the
+script had a default filter to remove all backup files (-xname='~$')
+which would have to mix with additional command line filters.  The following
+would try to search for bash files (files whose first line starts with
 #!/bin/bash) that aren't backups:
 
-    $ gre -x='~$' -line1='^#!/bin/bash'
+    $ gre -xname='~$' -line1='^#!/bin/bash'
 
 It wouldn't work if they weren't independent: filters are additive,
 so this would have added all files which are not backups then add
@@ -161,39 +160,39 @@ this work:
 
 which will find all html and javascript files.
 
-If I added the builtin filter after the command line arguments:
+If I added the builtin filters after the command line arguments:
 
-    $ gre -line1='^#!/bin/bash' -x='~$'
+    $ gre -line1='^#!/bin/bash' -xname='~$'
 
 Then you wouldn't have a chance to disable it:
 
-    $ gre -line1='^#!/bin/bash' -nox='~$' -x='~$'
+    $ gre -line1='^#!/bin/bash' -noxname='~$' -xname='~$'
 
 It would still filter out the backup files.
 
-So the "includes" and "excludes" need to be independent of each
-other. The result should be intuitive. For example, if you want to
+The result should be intuitive. For example, if you want to
 search everything except one file that's messing up the search add:
 
-    $ gre -x=INBOX.mbox -ext=mbox qwerty
+    $ gre -xname=INBOX.mbox -ext=mbox qwerty
 
-You don't have to worry about order either.
+and you wouldn't have to worry about order of these filters.
 
-If you want to remove all the builtin excluding filters, use -X on
-the command line. By default, gre will exclude backup files,
-swap files, core dumps, .git directories, .svn directories, binary
-files, minimized js files, and more. See the output from -combos
-for the full list.
+If you want to remove all the builtin "exclude" filters, use -x on
+the command line. By default, gre will exclude backup files, swap
+files, core dumps, .git directories, .svn directories, binary files,
+minimized js files, and more. See the output of -c for the full
+list.
 
 "exclude" filters also have another property which the regular
 "include" filters don't have: They prune the recursive file search.
-So -xe=.git will prevent any file under a .git directory from
-being searched (the extra e at the end of -xe means to use
-string equality not regexp's for the match). Normal "inclusive"
+So -xnamee=.git will prevent any file under a .git directory from
+being searched (the extra e at the end of -xname means to use
+string equality not regexp's for the match). Normal "include"
 filters do not execute on directories.
 
-You can control the depth of the recursion with the -d option. -d1
-disables recursion. -d0 is unlimited. -d2 will go 2 levels deep.
+You can control the depth of the recursion with the -d option.  -d0
+is for unlimited recursion (the default), -d1 disables recursion,
+-d2 will only let recursion go two levels deep.
 
 Files listed on the command line are always searched regardless of
 the filters.
@@ -204,14 +203,29 @@ you might end up in an infinite loop.
 =head1 IDEAS
 
 You can do multiline regexp's '^sub.*^\}' (with the addition of the
--multiline option)
+-m option)
 
 The script doesn't bundle options so it only uses one dash for the
-long options. Many longer options have shorter equivalents, e.g.
--multiline is -m.
+long options.
 
 Options that take arguments can be given like -ext=foo or -ext foo.
 
+Option names for file filters can include:
+
+=over
+
+=item * "no" filters files out,
+
+=item * "i" makes the regexp case insensitive,
+
+=item * "e" makes the match use string equality instead of regexp,
+
+=item * "r" makes the match use regexp instead of string equality,
+
+=item * "x" makes it an excluding filter
+
+=back
+
 =head1 OUTPUT STYLES
 
 You can specify the output style with the -y option:
@@ -247,15 +261,15 @@ line filters. For example:
 
     -xpath=template_compiles
     -xpath=templates/cache
-    -xe=yui
+    -xnamee=yui
 
 =head1 INSTALLATION
 
-gre is a single script with no dependencies. copy it to a place in your
+gre is a single script with no dependencies. Copy it to a place in your
 $PATH and it should work as-is. The App::Gre module is just an unused
 placeholder module to make it work with CPAN.
 
-You can also run "cpan App::Gre".
+You can also run "cpan App::Gre" to install it.
 
 =head1 SEE ALSO
 
